# Installation

## Stable release

To install dep-check, run this command in your terminal:

    pip install dep-check

This is the preferred method to install dep-check, as it will always
install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

## From sources

The sources for dep-check can be downloaded from the [Github repo](https://github.com/lumapps/dep-check).

You can either clone the public repository:

    git clone git://github.com/lumapps/dep-check

Or download the [tarball](https://github.com/lumapps/dep-check/tarball/master):

    curl  -OL https://github.com/lumapps/dep-check/tarball/master

Once you have a copy of the source, you can install it with:

    python setup.py install
